Runtime manager plugin
======================

.. automodule:: vmshepherd.runtime.abstract

.. autoclass:: vmshepherd.runtime.abstract.AbstractRuntimeData
    :members: _acquire_lock, _release_lock, _get_preset_data, _set_preset_data
    :show-inheritance:
